@@ -147,8 +147,7 @@ class PKMClient(object):
             print(getSt, getTx, file=sys.stderr)
             inv = getTx
             inv.update(invocationUpdate)
-        return self.call(method='PUT', path='invocations/'+project_id,
-                         payload=json.dumps([inv]))
+        return self.call(method='PUT', path='invocations/'+project_id, payload=[inv])
 
 
 class Log(object):
